@@ -26,9 +26,7 @@ OC.L10N.register(
     "Manually" : "Manuálne",
     "Alphabetically" : "Abecedne",
     "Task is completed" : "Úloha je dokončená",
-    "Add a task to \"{calendar}\"..." : "Pridať úlohu do kalendára \"{calendar}\"...",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n dokončená úloha","%n dokončené úlohy","%n dokončených úloh","%n dokončených úloh"],
-    "Add a task to \"{calendar}\"…" : "Pridať úlohu do kalendára \"{calendar}\"…",
     "Tomorrow" : "Zajtra",
     "Set start date" : "Nastaviť dátum začatia",
     "Set due date" : "Nastaviť do dátumu",
