@@ -9,7 +9,7 @@ OC.L10N.register(
     "Current" : "当前",
     "Completed" : "完成",
     "The Tasks app for Nextcloud" : "Nextcloud 任务应用",
-    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates, reminder times, mark them as important, and add comments on them. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client - Thunderbird, Evolution, KDE Kontact, iCal... - just add the calendar as a remote calendar in you client). You can download your tasks as ICS files using the download button for each calendar." : "启用后，Nextcloud 应用菜单中将显示一个新的“任务”菜单。从那里，您可以添加和删除任务，编辑其标题，描述，开始和截止日期，提醒时间，将其标记为重要，并添加注释。任务可以在用户之间共享。可以使用 CalDav 同步任务（每个任务列表链接到 Nextcloud 日历，将其同步到本地客户端 - Thunderbird，Evolution，KDE Kontact，iCal ... - 只需将日历添加为客户端中的远程日历）。您可以使用每个日历的下载按钮将任务下载为 ICS 文件。",
+    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates, reminder times, mark them as important, and add comments on them. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client - Thunderbird, Evolution, KDE Kontact, iCal... - just add the calendar as a remote calendar in you client). You can download your tasks as ICS files using the download button for each calendar." : "在启用后，Nextcloud 应用菜单中将显示一个新的“任务”菜单。从那里，您可以添加和删除任务，编辑其标题，描述，开始和截止日期，提醒时间，将其标记为重要，并添加注释。任务可以在用户之间共享。可以使用 CalDav 同步任务（每个任务列表链接到 Nextcloud 日历，将其同步到本地客户端 - Thunderbird，Evolution，KDE Kontact，iCal ... - 只需将日历添加为客户端中的远程日历）。您可以使用每个日历的下载按钮将任务下载为 ICS 文件。",
     "Share with users or groups" : "和用户或者群组共享",
     "No users or groups" : "无用户或群组",
     "can edit" : "可编辑",
@@ -19,10 +19,10 @@ OC.L10N.register(
     "Cancel" : "取消",
     "Delete all completed tasks." : "删除所有已完成任务。",
     "Delete completed tasks." : "删除已完成任务。",
-    "Deleted all completed tasks from calendar \"{calendarName}\"." : "从日历 \"{calendarName}\" 中删除所有已完成任务。",
+    "Deleted all completed tasks from calendar \"%s\"." : "从日历 \"%s\" 中删除所有已完成任务。",
     "No errors" : "没有错误",
     "Open your browser console for more details" : "打开您的浏览器控制台以获取更多详细信息",
-    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendarName}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendarName}\"._" : ["此操作将从日历 \"{calendarName}\" 中删除 {taskCount} 个已完成任务及其子任务。"],
+    "_This will delete {taskCount} completed task and its subtasks from calendar \"%s\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"%s\"._" : ["此操作将从%s日历 \"{calendarName}\" 中删除 {taskCount} 个已完成任务及其子任务。"],
     "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["无法删除 {failedCount} 个任务。"],
     "Load all completed tasks." : "载入所有已完成任务。",
     "Change sort order" : "更改排序",
@@ -51,13 +51,12 @@ OC.L10N.register(
     "[Yesterday]" : "[昨天]",
     "[Today]" : "[今天]",
     "[Tomorrow]" : "[明天]",
-    "Add a subtask to \"{task}\"…" : "添加子任务到 \"{task}\" ...",
-    "Add a task to \"{calendar}\"..." : "添加任务到 \"{calendar}\" ...",
+    "Add a subtask to \"%s\"…" : "添加子任务到 \"%s\" ...",
+    "Add a task to \"%s\"…" : "添加任务到 \"%s\" ...",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n 任务完成"],
-    "Add an important task to \"{calendar}\"…" : "添加重要任务到 \"{calendar}\" ...",
-    "Add a task due today to \"{calendar}\"…" : "添加今天截止的任务到 \"{calendar}\" ...",
-    "Add a current task to \"{calendar}\"…" : "添加当前任务到 \"{calendar}\" ...",
-    "Add a task to \"{calendar}\"…" : "添加任务到 \"{calendar}\" ...",
+    "Add an important task to \"%s\"…" : "添加重要任务到 \"%s\" ...",
+    "Add a task due today to \"%s\"…" : "添加今天截止的任务到 \"%s\" ...",
+    "Add a current task to \"%s\"…" : "添加当前任务到 \"%s\" ...",
     "Tomorrow" : "明天",
     "Set start date" : "设置开始日期",
     "Set start time" : "设置开始时间",
